@@ -1,13 +1,11 @@
 require 'spec_helper'
 
 describe U2F::SignRequest do
-  let(:app_id) { 'http://example.com' }
-  let(:challenge) { 'fEnc9oV79EaBgK5BoNERU5gPKM2XGYWrz4fUjgc0Q7g' }
   let(:key_handle) do
     'CTUayZo8hCBeC-sGQJChC0wW-bBg99bmOlGCgw8XGq4dLsxO3yWh9mRYArZxocP5hBB1pEGB3bbJYiM-5acc5w=='
   end
   let(:sign_request) do
-    U2F::SignRequest.new(key_handle, challenge, app_id)
+    U2F::SignRequest.new(key_handle)
   end
 
   describe '#to_json' do
@@ -15,10 +13,8 @@ describe U2F::SignRequest do
     it do
       is_expected.to match_json_expression(
         version: String,
-        appId: String,
-        challenge: String,
         keyHandle: String
       )
     end
   end
-end
\ No newline at end of file
+end
